@@ -6,13 +6,15 @@
 require('es6-promise/auto');  // polyfill Promise on IE
 
 import {
-  PageConfig, URLExt
+  PageConfig
 } from '@jupyterlab/coreutils';
 
-__webpack_public_path__ = PageConfig.getOption('bundleUrl');
+// eslint-disable-next-line no-undef
+__webpack_public_path__ = PageConfig.getOption('fullStaticUrl') + '/';
 
-// This needs to come after __webpack_public_path__ is set.
-require('font-awesome/css/font-awesome.min.css');
+// This must be after the public path is set.
+// This cannot be extracted because the public path is dynamic.
+require('./imports.css');
 
 /**
  * The main entry point for the application.
@@ -67,6 +69,8 @@ function main() {
 
   // Handle the registered mime extensions.
   var mimeExtensions = [];
+  var extension;
+  var extMod;
   try {
     if (isDeferred('')) {
       deferred.matches.push('');
@@ -75,12 +79,12 @@ function main() {
     if (isDisabled('@jupyterlab/javascript-extension')) {
       disabled.matches.push('@jupyterlab/javascript-extension');
     } else {
-      var module = require('@jupyterlab/javascript-extension/');
-      var extension = module.default;
+      extMod = require('@jupyterlab/javascript-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -110,47 +114,12 @@ function main() {
     if (isDisabled('@jupyterlab/json-extension')) {
       disabled.matches.push('@jupyterlab/json-extension');
     } else {
-      var module = require('@jupyterlab/json-extension/');
-      var extension = module.default;
+      extMod = require('@jupyterlab/json-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
-      }
-
-      if (Array.isArray(extension)) {
-        extension.forEach(function(plugin) {
-          if (isDeferred(plugin.id)) {
-            deferred.matches.push(plugin.id);
-            ignorePlugins.push(plugin.id);
-          }
-          if (isDisabled(plugin.id)) {
-            disabled.matches.push(plugin.id);
-            return;
-          }
-          mimeExtensions.push(plugin);
-        });
-      } else {
-        mimeExtensions.push(extension);
-      }
-    }
-  } catch (e) {
-    console.error(e);
-  }
-  try {
-    if (isDeferred('')) {
-      deferred.matches.push('');
-      ignorePlugins.push('');
-    }
-    if (isDisabled('@jupyterlab/markdownviewer-extension')) {
-      disabled.matches.push('@jupyterlab/markdownviewer-extension');
-    } else {
-      var module = require('@jupyterlab/markdownviewer-extension/');
-      var extension = module.default;
-
-      // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -180,47 +149,12 @@ function main() {
     if (isDisabled('@jupyterlab/pdf-extension')) {
       disabled.matches.push('@jupyterlab/pdf-extension');
     } else {
-      var module = require('@jupyterlab/pdf-extension/');
-      var extension = module.default;
+      extMod = require('@jupyterlab/pdf-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
-      }
-
-      if (Array.isArray(extension)) {
-        extension.forEach(function(plugin) {
-          if (isDeferred(plugin.id)) {
-            deferred.matches.push(plugin.id);
-            ignorePlugins.push(plugin.id);
-          }
-          if (isDisabled(plugin.id)) {
-            disabled.matches.push(plugin.id);
-            return;
-          }
-          mimeExtensions.push(plugin);
-        });
-      } else {
-        mimeExtensions.push(extension);
-      }
-    }
-  } catch (e) {
-    console.error(e);
-  }
-  try {
-    if (isDeferred('')) {
-      deferred.matches.push('');
-      ignorePlugins.push('');
-    }
-    if (isDisabled('@jupyterlab/vdom-extension')) {
-      disabled.matches.push('@jupyterlab/vdom-extension');
-    } else {
-      var module = require('@jupyterlab/vdom-extension/');
-      var extension = module.default;
-
-      // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -250,12 +184,47 @@ function main() {
     if (isDisabled('@jupyterlab/vega4-extension')) {
       disabled.matches.push('@jupyterlab/vega4-extension');
     } else {
-      var module = require('@jupyterlab/vega4-extension/');
-      var extension = module.default;
+      extMod = require('@jupyterlab/vega4-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
+      }
+
+      if (Array.isArray(extension)) {
+        extension.forEach(function(plugin) {
+          if (isDeferred(plugin.id)) {
+            deferred.matches.push(plugin.id);
+            ignorePlugins.push(plugin.id);
+          }
+          if (isDisabled(plugin.id)) {
+            disabled.matches.push(plugin.id);
+            return;
+          }
+          mimeExtensions.push(plugin);
+        });
+      } else {
+        mimeExtensions.push(extension);
+      }
+    }
+  } catch (e) {
+    console.error(e);
+  }
+  try {
+    if (isDeferred('')) {
+      deferred.matches.push('');
+      ignorePlugins.push('');
+    }
+    if (isDisabled('@jupyterlab/vega5-extension')) {
+      disabled.matches.push('@jupyterlab/vega5-extension');
+    } else {
+      extMod = require('@jupyterlab/vega5-extension/');
+      extension = extMod.default;
+
+      // Handle CommonJS exports.
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -287,12 +256,12 @@ function main() {
     if (isDisabled('@jupyterlab/application-extension')) {
       disabled.matches.push('@jupyterlab/application-extension');
     } else {
-      module = require('@jupyterlab/application-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/application-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -322,12 +291,12 @@ function main() {
     if (isDisabled('@jupyterlab/apputils-extension')) {
       disabled.matches.push('@jupyterlab/apputils-extension');
     } else {
-      module = require('@jupyterlab/apputils-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/apputils-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -357,12 +326,12 @@ function main() {
     if (isDisabled('@jupyterlab/codemirror-extension')) {
       disabled.matches.push('@jupyterlab/codemirror-extension');
     } else {
-      module = require('@jupyterlab/codemirror-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/codemirror-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -392,12 +361,12 @@ function main() {
     if (isDisabled('@jupyterlab/completer-extension')) {
       disabled.matches.push('@jupyterlab/completer-extension');
     } else {
-      module = require('@jupyterlab/completer-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/completer-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -427,12 +396,12 @@ function main() {
     if (isDisabled('@jupyterlab/console-extension')) {
       disabled.matches.push('@jupyterlab/console-extension');
     } else {
-      module = require('@jupyterlab/console-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/console-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -462,12 +431,12 @@ function main() {
     if (isDisabled('@jupyterlab/csvviewer-extension')) {
       disabled.matches.push('@jupyterlab/csvviewer-extension');
     } else {
-      module = require('@jupyterlab/csvviewer-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/csvviewer-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -497,12 +466,47 @@ function main() {
     if (isDisabled('@jupyterlab/docmanager-extension')) {
       disabled.matches.push('@jupyterlab/docmanager-extension');
     } else {
-      module = require('@jupyterlab/docmanager-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/docmanager-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
+      }
+
+      if (Array.isArray(extension)) {
+        extension.forEach(function(plugin) {
+          if (isDeferred(plugin.id)) {
+            deferred.matches.push(plugin.id);
+            ignorePlugins.push(plugin.id);
+          }
+          if (isDisabled(plugin.id)) {
+            disabled.matches.push(plugin.id);
+            return;
+          }
+          register.push(plugin);
+        });
+      } else {
+        register.push(extension);
+      }
+    }
+  } catch (e) {
+    console.error(e);
+  }
+  try {
+    if (isDeferred('')) {
+      deferred.matches.push('');
+      ignorePlugins.push('');
+    }
+    if (isDisabled('@jupyterlab/documentsearch-extension')) {
+      disabled.matches.push('@jupyterlab/documentsearch-extension');
+    } else {
+      extMod = require('@jupyterlab/documentsearch-extension/');
+      extension = extMod.default;
+
+      // Handle CommonJS exports.
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -532,47 +536,12 @@ function main() {
     if (isDisabled('@jupyterlab/extensionmanager-extension')) {
       disabled.matches.push('@jupyterlab/extensionmanager-extension');
     } else {
-      module = require('@jupyterlab/extensionmanager-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/extensionmanager-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
-      }
-
-      if (Array.isArray(extension)) {
-        extension.forEach(function(plugin) {
-          if (isDeferred(plugin.id)) {
-            deferred.matches.push(plugin.id);
-            ignorePlugins.push(plugin.id);
-          }
-          if (isDisabled(plugin.id)) {
-            disabled.matches.push(plugin.id);
-            return;
-          }
-          register.push(plugin);
-        });
-      } else {
-        register.push(extension);
-      }
-    }
-  } catch (e) {
-    console.error(e);
-  }
-  try {
-    if (isDeferred('')) {
-      deferred.matches.push('');
-      ignorePlugins.push('');
-    }
-    if (isDisabled('@jupyterlab/faq-extension')) {
-      disabled.matches.push('@jupyterlab/faq-extension');
-    } else {
-      module = require('@jupyterlab/faq-extension/');
-      extension = module.default;
-
-      // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -602,12 +571,12 @@ function main() {
     if (isDisabled('@jupyterlab/filebrowser-extension')) {
       disabled.matches.push('@jupyterlab/filebrowser-extension');
     } else {
-      module = require('@jupyterlab/filebrowser-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/filebrowser-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -637,12 +606,12 @@ function main() {
     if (isDisabled('@jupyterlab/fileeditor-extension')) {
       disabled.matches.push('@jupyterlab/fileeditor-extension');
     } else {
-      module = require('@jupyterlab/fileeditor-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/fileeditor-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -672,12 +641,82 @@ function main() {
     if (isDisabled('@jupyterlab/help-extension')) {
       disabled.matches.push('@jupyterlab/help-extension');
     } else {
-      module = require('@jupyterlab/help-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/help-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
+      }
+
+      if (Array.isArray(extension)) {
+        extension.forEach(function(plugin) {
+          if (isDeferred(plugin.id)) {
+            deferred.matches.push(plugin.id);
+            ignorePlugins.push(plugin.id);
+          }
+          if (isDisabled(plugin.id)) {
+            disabled.matches.push(plugin.id);
+            return;
+          }
+          register.push(plugin);
+        });
+      } else {
+        register.push(extension);
+      }
+    }
+  } catch (e) {
+    console.error(e);
+  }
+  try {
+    if (isDeferred('')) {
+      deferred.matches.push('');
+      ignorePlugins.push('');
+    }
+    if (isDisabled('@jupyterlab/htmlviewer-extension')) {
+      disabled.matches.push('@jupyterlab/htmlviewer-extension');
+    } else {
+      extMod = require('@jupyterlab/htmlviewer-extension/');
+      extension = extMod.default;
+
+      // Handle CommonJS exports.
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
+      }
+
+      if (Array.isArray(extension)) {
+        extension.forEach(function(plugin) {
+          if (isDeferred(plugin.id)) {
+            deferred.matches.push(plugin.id);
+            ignorePlugins.push(plugin.id);
+          }
+          if (isDisabled(plugin.id)) {
+            disabled.matches.push(plugin.id);
+            return;
+          }
+          register.push(plugin);
+        });
+      } else {
+        register.push(extension);
+      }
+    }
+  } catch (e) {
+    console.error(e);
+  }
+  try {
+    if (isDeferred('')) {
+      deferred.matches.push('');
+      ignorePlugins.push('');
+    }
+    if (isDisabled('@jupyterlab/hub-extension')) {
+      disabled.matches.push('@jupyterlab/hub-extension');
+    } else {
+      extMod = require('@jupyterlab/hub-extension/');
+      extension = extMod.default;
+
+      // Handle CommonJS exports.
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -707,12 +746,12 @@ function main() {
     if (isDisabled('@jupyterlab/imageviewer-extension')) {
       disabled.matches.push('@jupyterlab/imageviewer-extension');
     } else {
-      module = require('@jupyterlab/imageviewer-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/imageviewer-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -742,12 +781,12 @@ function main() {
     if (isDisabled('@jupyterlab/inspector-extension')) {
       disabled.matches.push('@jupyterlab/inspector-extension');
     } else {
-      module = require('@jupyterlab/inspector-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/inspector-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -777,12 +816,12 @@ function main() {
     if (isDisabled('@jupyterlab/launcher-extension')) {
       disabled.matches.push('@jupyterlab/launcher-extension');
     } else {
-      module = require('@jupyterlab/launcher-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/launcher-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -812,12 +851,47 @@ function main() {
     if (isDisabled('@jupyterlab/mainmenu-extension')) {
       disabled.matches.push('@jupyterlab/mainmenu-extension');
     } else {
-      module = require('@jupyterlab/mainmenu-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/mainmenu-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
+      }
+
+      if (Array.isArray(extension)) {
+        extension.forEach(function(plugin) {
+          if (isDeferred(plugin.id)) {
+            deferred.matches.push(plugin.id);
+            ignorePlugins.push(plugin.id);
+          }
+          if (isDisabled(plugin.id)) {
+            disabled.matches.push(plugin.id);
+            return;
+          }
+          register.push(plugin);
+        });
+      } else {
+        register.push(extension);
+      }
+    }
+  } catch (e) {
+    console.error(e);
+  }
+  try {
+    if (isDeferred('')) {
+      deferred.matches.push('');
+      ignorePlugins.push('');
+    }
+    if (isDisabled('@jupyterlab/markdownviewer-extension')) {
+      disabled.matches.push('@jupyterlab/markdownviewer-extension');
+    } else {
+      extMod = require('@jupyterlab/markdownviewer-extension/');
+      extension = extMod.default;
+
+      // Handle CommonJS exports.
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -847,12 +921,12 @@ function main() {
     if (isDisabled('@jupyterlab/mathjax2-extension')) {
       disabled.matches.push('@jupyterlab/mathjax2-extension');
     } else {
-      module = require('@jupyterlab/mathjax2-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/mathjax2-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -882,12 +956,12 @@ function main() {
     if (isDisabled('@jupyterlab/notebook-extension')) {
       disabled.matches.push('@jupyterlab/notebook-extension');
     } else {
-      module = require('@jupyterlab/notebook-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/notebook-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -917,12 +991,12 @@ function main() {
     if (isDisabled('@jupyterlab/rendermime-extension')) {
       disabled.matches.push('@jupyterlab/rendermime-extension');
     } else {
-      module = require('@jupyterlab/rendermime-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/rendermime-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -952,12 +1026,12 @@ function main() {
     if (isDisabled('@jupyterlab/running-extension')) {
       disabled.matches.push('@jupyterlab/running-extension');
     } else {
-      module = require('@jupyterlab/running-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/running-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -987,12 +1061,12 @@ function main() {
     if (isDisabled('@jupyterlab/settingeditor-extension')) {
       disabled.matches.push('@jupyterlab/settingeditor-extension');
     } else {
-      module = require('@jupyterlab/settingeditor-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/settingeditor-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -1022,12 +1096,47 @@ function main() {
     if (isDisabled('@jupyterlab/shortcuts-extension')) {
       disabled.matches.push('@jupyterlab/shortcuts-extension');
     } else {
-      module = require('@jupyterlab/shortcuts-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/shortcuts-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
+      }
+
+      if (Array.isArray(extension)) {
+        extension.forEach(function(plugin) {
+          if (isDeferred(plugin.id)) {
+            deferred.matches.push(plugin.id);
+            ignorePlugins.push(plugin.id);
+          }
+          if (isDisabled(plugin.id)) {
+            disabled.matches.push(plugin.id);
+            return;
+          }
+          register.push(plugin);
+        });
+      } else {
+        register.push(extension);
+      }
+    }
+  } catch (e) {
+    console.error(e);
+  }
+  try {
+    if (isDeferred('')) {
+      deferred.matches.push('');
+      ignorePlugins.push('');
+    }
+    if (isDisabled('@jupyterlab/statusbar-extension')) {
+      disabled.matches.push('@jupyterlab/statusbar-extension');
+    } else {
+      extMod = require('@jupyterlab/statusbar-extension/');
+      extension = extMod.default;
+
+      // Handle CommonJS exports.
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -1057,12 +1166,12 @@ function main() {
     if (isDisabled('@jupyterlab/tabmanager-extension')) {
       disabled.matches.push('@jupyterlab/tabmanager-extension');
     } else {
-      module = require('@jupyterlab/tabmanager-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/tabmanager-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -1092,12 +1201,12 @@ function main() {
     if (isDisabled('@jupyterlab/terminal-extension')) {
       disabled.matches.push('@jupyterlab/terminal-extension');
     } else {
-      module = require('@jupyterlab/terminal-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/terminal-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -1127,12 +1236,12 @@ function main() {
     if (isDisabled('@jupyterlab/theme-dark-extension')) {
       disabled.matches.push('@jupyterlab/theme-dark-extension');
     } else {
-      module = require('@jupyterlab/theme-dark-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/theme-dark-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -1162,12 +1271,12 @@ function main() {
     if (isDisabled('@jupyterlab/theme-light-extension')) {
       disabled.matches.push('@jupyterlab/theme-light-extension');
     } else {
-      module = require('@jupyterlab/theme-light-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/theme-light-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -1197,12 +1306,47 @@ function main() {
     if (isDisabled('@jupyterlab/tooltip-extension')) {
       disabled.matches.push('@jupyterlab/tooltip-extension');
     } else {
-      module = require('@jupyterlab/tooltip-extension/');
-      extension = module.default;
+      extMod = require('@jupyterlab/tooltip-extension/');
+      extension = extMod.default;
 
       // Handle CommonJS exports.
-      if (!module.hasOwnProperty('__esModule')) {
-        extension = module;
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
+      }
+
+      if (Array.isArray(extension)) {
+        extension.forEach(function(plugin) {
+          if (isDeferred(plugin.id)) {
+            deferred.matches.push(plugin.id);
+            ignorePlugins.push(plugin.id);
+          }
+          if (isDisabled(plugin.id)) {
+            disabled.matches.push(plugin.id);
+            return;
+          }
+          register.push(plugin);
+        });
+      } else {
+        register.push(extension);
+      }
+    }
+  } catch (e) {
+    console.error(e);
+  }
+  try {
+    if (isDeferred('')) {
+      deferred.matches.push('');
+      ignorePlugins.push('');
+    }
+    if (isDisabled('@jupyterlab/vdom-extension')) {
+      disabled.matches.push('@jupyterlab/vdom-extension');
+    } else {
+      extMod = require('@jupyterlab/vdom-extension/');
+      extension = extMod.default;
+
+      // Handle CommonJS exports.
+      if (!extMod.hasOwnProperty('__esModule')) {
+        extension = extMod;
       }
 
       if (Array.isArray(extension)) {
@@ -1250,7 +1394,7 @@ function main() {
     var reported = false;
     var timeout = 25000;
 
-    var report = function(errors) {
+    var report = function() {
       if (reported) {
         return;
       }
